#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec-iso8601
version:              1.0.2.0
visibility:           public
id:                   attoparsec-iso8601-1.0.2.0-50ZSb8pGqxV3LEsKG61fmD
key:                  attoparsec-iso8601-1.0.2.0-50ZSb8pGqxV3LEsKG61fmD
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson.
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  f0062ae2c08cfc59127ba603c8353d82
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/attoparsec-iso8601-1.0.2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/attoparsec-iso8601-1.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/attoparsec-iso8601-1.0.2.0
hs-libraries:         HSattoparsec-iso8601-1.0.2.0-50ZSb8pGqxV3LEsKG61fmD
depends:
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    base-compat-batteries-0.11.2-Adi2U3TFDt9D7s2pHONdZC text-1.2.4.1
    time-1.9.3 time-compat-1.9.6-EDzX7ajtkgGWnlwWEKmRn

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

